@@ -1115,6 +1115,12 @@ func (s *Suite) Test_PatchChecker_checkCanonicalPatchName(c *check.C) {
 		"file_underscore.py",
 		nil...)
 
+	// pkgtools/pkgdiff converts "_" to "__".
+	test(
+		"patch-file__underscore.py",
+		"file_underscore.py",
+		nil...)
+
 	test(
 		"patch-one.py",
 		"two.py",
@@ -1134,13 +1140,47 @@ func (s *Suite) Test_PatchChecker_checkCanonicalPatchName(c *check.C) {
 		"./src/subdir/file",
 		nil...)
 
-	// It's not enough if the patch name is an arbitrary suffix of the
-	// patched file. The only allowed abbreviation is the basename.
+	// Allow a prefix to be omitted from the patch name,
+	// as the remaining name is still descriptive enough.
+	test(
+		"patch-libc-0.2.168_src_unix_bsd_netbsdlike_netbsd_mod.rs",
+		"vendor/libc-0.2.168/src/unix/bsd/netbsdlike/netbsd/mod.rs",
+		nil...)
+	test(
+		"patch-src_unix_bsd_netbsdlike_netbsd_mod.rs",
+		"vendor/libc-0.2.168/src/unix/bsd/netbsdlike/netbsd/mod.rs",
+		nil...)
+	test(
+		"patch-netbsd_mod.rs",
+		"vendor/libc-0.2.168/src/unix/bsd/netbsdlike/netbsd/mod.rs",
+		nil...)
+	test(
+		"patch-mod.rs",
+		"vendor/libc-0.2.168/src/unix/bsd/netbsdlike/netbsd/mod.rs",
+		nil...)
+
+	// This patch name is too short to identify the patched file,
+	// but the pattern "patch-[a-z][a-z]" has its historic use.
+	test(
+		"patch-rs",
+		"vendor/libc-0.2.168/src/unix/bsd/netbsdlike/netbsd/mod.rs",
+		nil...)
+
+	// This patch name is too short to identify the patched file.
+	test(
+		"patch-cxx",
+		"src/unix/bsd/netbsdlike/netbsd/mod.cxx",
+		"WARN: patch-cxx: The patch file should be named "+
+			"\"patch-src_unix_bsd_netbsdlike_netbsd_mod.cxx\" "+
+			"to match the patched file "+
+			"\"src/unix/bsd/netbsdlike/netbsd/mod.cxx\".")
 	test(
 		"patch-c",
 		"./src/subdir/file.c",
-		"WARN: patch-c: The patch file should be named \"patch-src_subdir_file.c\" "+
-			"to match the patched file \"./src/subdir/file.c\".")
+		"WARN: patch-c: The patch file should be named "+
+			"\"patch-src_subdir_file.c\" "+
+			"to match the patched file "+
+			"\"./src/subdir/file.c\".")
 
 	// Allow existing patches to differ in case.
 	// Most packages won't have files that could conflict on a
@@ -1149,6 +1189,12 @@ func (s *Suite) Test_PatchChecker_checkCanonicalPatchName(c *check.C) {
 		"patch-upper",
 		"./src/UPPER",
 		nil...)
+
+	// Leading "../" components need not be encoded in the patch name.
+	test(
+		"patch-dir-subdir-file-c",
+		"../dir/subdir/file.c",
+		nil...)
 }
 
 // Autogenerated "comments" from Git or other tools don't count as real
