@@ -195,6 +195,18 @@ func (s *Suite) Test_CheckLinesPlist__PLIST_SRC(c *check.C) {
 	t.CheckOutputEmpty()
 }
 
+func (s *Suite) Test_CheckLinesPlist__only_comments(c *check.C) {
+	t := s.Init(c)
+
+	lines := t.NewLines("PLIST",
+		PlistCvsID,
+		"@comment intentionally left empty")
+
+	CheckLinesPlist(nil, lines)
+
+	t.CheckOutputEmpty()
+}
+
 func (s *Suite) Test_PlistChecker__autofix(c *check.C) {
 	t := s.Init(c)
 
@@ -231,6 +243,7 @@ func (s *Suite) Test_PlistChecker__autofix(c *check.C) {
 		"NOTE: ~/PLIST:6: PLIST files should use \"man/\" instead of \"${PKGMANDIR}\".")
 
 	t.SetUpCommandLine("-Wall", "--autofix")
+	lines = Load(t.File("PLIST"), 0)
 	CheckLinesPlist(nil, lines)
 
 	t.CheckOutputLines(
@@ -286,7 +299,7 @@ func (s *Suite) Test_PlistChecker__remove_same_entries(c *check.C) {
 		"ERROR: ~/PLIST:8: Duplicate filename \"bin/true\", already appeared in line 3.")
 
 	t.SetUpCommandLine("-Wall", "--autofix")
-
+	lines = Load(t.File("PLIST"), MustSucceed|NotEmpty)
 	CheckLinesPlist(nil, lines)
 
 	t.CheckOutputLines(
@@ -446,9 +459,22 @@ func (s *Suite) Test_NewPlistChecker(c *check.C) {
 
 	ck := NewPlistChecker(pkg)
 
-	t.CheckEquals(ck.pkg, pkg)
-	t.CheckNotNil(ck.allDirs)
-	t.CheckNotNil(ck.allFiles)
+	t.CheckEquals(ck.pathChecker.pkg, pkg)
+	t.CheckNotNil(ck.pathChecker.allDirs)
+	t.CheckNotNil(ck.pathChecker.allFiles)
+}
+
+func (s *Suite) Test_PlistChecker_Check(c *check.C) {
+	t := s.Init(c)
+
+	lines := t.NewLines("PLIST",
+		"bin/subdir/program")
+	ck := NewPlistChecker(nil)
+
+	ck.Check(lines)
+
+	t.CheckOutputLines(
+		"WARN: PLIST:1: The bin/ directory should not have subdirectories.")
 }
 
 func (s *Suite) Test_PlistChecker_Load__common_end(c *check.C) {
@@ -477,29 +503,16 @@ func (s *Suite) Test_PlistChecker_Load__common_end(c *check.C) {
 	// But the files and directories from PLIST.common are registered,
 	// to check for duplicates and to make these lists available to
 	// the package being checked, for cross-validation.
-	t.CheckNil(ck.allFiles["bin/plist"])
+	t.CheckNil(ck.pathChecker.allFiles["bin/plist"])
 	t.CheckEquals(
-		ck.allFiles["bin/plist_common"].Line.String(),
+		ck.pathChecker.allFiles["bin/plist_common"].Line.String(),
 		"PLIST.common:2: bin/plist_common")
 	t.CheckEquals(
-		ck.allFiles["bin/plist_common_end"].Line.String(),
+		ck.pathChecker.allFiles["bin/plist_common_end"].Line.String(),
 		"PLIST.common_end:2: bin/plist_common_end")
 }
 
-func (s *Suite) Test_PlistChecker_Check(c *check.C) {
-	t := s.Init(c)
-
-	lines := t.NewLines("PLIST",
-		"bin/subdir/program")
-	ck := NewPlistChecker(nil)
-
-	ck.Check(lines)
-
-	t.CheckOutputLines(
-		"WARN: PLIST:1: The bin/ directory should not have subdirectories.")
-}
-
-func (s *Suite) Test_PlistChecker_newLines(c *check.C) {
+func (s *Suite) Test_extractPlistConditions(c *check.C) {
 	t := s.Init(c)
 
 	lines := t.NewLines("PLIST",
@@ -508,7 +521,7 @@ func (s *Suite) Test_PlistChecker_newLines(c *check.C) {
 		"${PLIST.abs}${PLIST.abs2}/bin/conditional-absolute",
 		"${PLIST.mod:Q}invalid")
 
-	plistLines := (*PlistChecker)(nil).newLines(lines)
+	plistLines := extractPlistConditions(lines)
 
 	// The invalid condition in line 4 is silently skipped when the
 	// lines are parsed. The actual check happens later.
@@ -535,31 +548,17 @@ func (s *Suite) Test_PlistChecker_collectFilesAndDirs(c *check.C) {
 		"/absolute",
 		"${PLIST.cond}/absolute",
 		"@exec ${MKDIR} %D//absolute")
-	ck := NewPlistChecker(nil)
-	plistLines := ck.newLines(lines)
+	plistLines := extractPlistConditions(lines)
 
+	ck := NewPlistChecker(nil)
 	ck.collectFilesAndDirs(plistLines)
 
-	t.CheckDeepEquals(keys(ck.allDirs),
+	t.CheckDeepEquals(keys(ck.pathChecker.allDirs),
 		[]string{"bin", "man", "man/man1"})
-	t.CheckDeepEquals(keys(ck.allFiles),
+	t.CheckDeepEquals(keys(ck.pathChecker.allFiles),
 		[]string{"bin/program", "man/man1/program.1"})
 }
 
-func (s *Suite) Test_PlistChecker_collectPath(c *check.C) {
-	t := s.Init(c)
-
-	line := t.NewLine("PLIST", 1, "a/b/c/program")
-	ck := NewPlistChecker(nil)
-
-	ck.collectPath("a/b/c/program", &PlistLine{line, nil, line.Text})
-
-	t.CheckDeepEquals(keys(ck.allDirs),
-		[]string{"a", "a/b", "a/b/c"})
-	t.CheckDeepEquals(keys(ck.allFiles),
-		[]string{"a/b/c/program"})
-}
-
 func (s *Suite) Test_PlistChecker_collectDirective(c *check.C) {
 	t := s.Init(c)
 
@@ -569,8 +568,8 @@ func (s *Suite) Test_PlistChecker_collectDirective(c *check.C) {
 
 		ck.collectDirective(&PlistLine{line, nil, line.Text})
 
-		t.CheckDeepEquals(keys(ck.allDirs), dirs)
-		t.CheckLen(keys(ck.allFiles), 0)
+		t.CheckDeepEquals(keys(ck.pathChecker.allDirs), dirs)
+		t.CheckLen(keys(ck.pathChecker.allFiles), 0)
 	}
 
 	test("@exec ${MKDIR} %D/a/b/c",
@@ -619,7 +618,21 @@ func (s *Suite) Test_PlistChecker_checkLine(c *check.C) {
 		"ERROR: PLIST:14: Invalid line type: <<<<<<<<< merge conflict")
 }
 
-func (s *Suite) Test_PlistChecker_checkPath__PKGMANDIR(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_collectPath(c *check.C) {
+	t := s.Init(c)
+
+	line := t.NewLine("PLIST", 1, "a/b/c/program")
+	ck := NewPlistChecker(nil)
+
+	ck.pathChecker.collectPath("a/b/c/program", &PlistLine{line, nil, line.Text})
+
+	t.CheckDeepEquals(keys(ck.pathChecker.allDirs),
+		[]string{"a", "a/b", "a/b/c"})
+	t.CheckDeepEquals(keys(ck.pathChecker.allFiles),
+		[]string{"a/b/c/program"})
+}
+
+func (s *Suite) Test_PlistPathChecker_Check__PKGMANDIR(c *check.C) {
 	t := s.Init(c)
 
 	lines := t.NewLines("PLIST",
@@ -632,7 +645,7 @@ func (s *Suite) Test_PlistChecker_checkPath__PKGMANDIR(c *check.C) {
 		"NOTE: PLIST:2: PLIST files should use \"man/\" instead of \"${PKGMANDIR}\".")
 }
 
-func (s *Suite) Test_PlistChecker_checkPathMisc__python_egg(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathMisc__python_egg(c *check.C) {
 	t := s.Init(c)
 
 	lines := t.NewLines("PLIST",
@@ -645,7 +658,7 @@ func (s *Suite) Test_PlistChecker_checkPathMisc__python_egg(c *check.C) {
 		"WARN: PLIST:2: Include \"../../lang/python/egg.mk\" instead of listing .egg-info files directly.")
 }
 
-func (s *Suite) Test_PlistChecker_checkPathMisc__python_egg_autofix(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathMisc__python_egg_autofix(c *check.C) {
 	t := s.Init(c)
 
 	t.SetUpCommandLine("--show-autofix")
@@ -674,7 +687,7 @@ func (s *Suite) Test_PlistChecker_checkPathMisc__python_egg_autofix(c *check.C)
 			"with \"${PYSITELIB}/${EGG_INFODIR}\".")
 }
 
-func (s *Suite) Test_PlistChecker_checkPathMisc__unwanted_entries(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathMisc__unwanted_entries(c *check.C) {
 	t := s.Init(c)
 
 	lines := t.SetUpFileLines("PLIST",
@@ -708,81 +721,7 @@ func (s *Suite) Test_PlistChecker_checkPathMisc__unwanted_entries(c *check.C) {
 		"ERROR: ~/PLIST:12: Paths in PLIST files must be canonical (t/non-canonical).")
 }
 
-func (s *Suite) Test_PlistChecker_checkPathNonAscii(c *check.C) {
-	t := s.Init(c)
-
-	t.SetUpCommandLine("-Wall", "--explain")
-	lines := t.NewLines("PLIST",
-		PlistCvsID,
-
-		"dir1/fr\xFCher", // German, "back then", encoded in ISO 8859-1
-
-		// Subsequent non-ASCII filenames do not generate further messages
-		// since these filenames typically appear in groups, and issuing
-		// too many warnings quickly gets boring.
-		"dir1/\u00C4thernetz", // German
-
-		// This ASCII-only pathname enables the check again.
-		"dir2/aaa",
-		"dir2/\u0633\u0644\u0627\u0645", // Arabic: salaam
-
-		"dir2/\uC548\uB148", // Korean: annyeong
-
-		// This ASCII-only pathname enables the check again.
-		"dir3/ascii-only",
-
-		// Any comment suppresses the check for the next contiguous
-		// sequence of non-ASCII filenames.
-		"@comment The next file is non-ASCII on purpose.",
-		"dir3/\U0001F603", // Smiling face with open mouth
-
-		// This ASCII-only pathname enables the check again.
-		"sbin/iconv",
-
-		"sbin/\U0001F603", // Smiling face with open mouth
-
-		// Directives other than comments do not allow non-ASCII.
-		"unicode/00FC/reset",
-		"@exec true",
-		"unicode/00FC/\u00FC", // u-umlaut
-	)
-
-	CheckLinesPlist(nil, lines)
-
-	t.CheckOutputLines(
-		"WARN: PLIST:2: Non-ASCII filename \"dir1/fr<0xFC>her\".",
-		"",
-		"\tThe great majority of filenames installed by pkgsrc packages are",
-		"\tASCII-only. Filenames containing non-ASCII characters can cause",
-		"\tvarious problems since their name may already be different when",
-		"\tanother character encoding is set in the locale.",
-		"",
-		"\tTo mark a filename as intentionally non-ASCII, insert a PLIST",
-		"\t@comment with a convincing reason directly above this line. That",
-		"\tcomment will allow this line and the lines directly below it to",
-		"\tcontain non-ASCII filenames.",
-		"",
-		"WARN: PLIST:5: Non-ASCII filename \"dir2/<U+0633><U+0644><U+0627><U+0645>\".",
-		"WARN: PLIST:11: Non-ASCII filename \"sbin/<U+1F603>\".",
-		"WARN: PLIST:14: Non-ASCII filename \"unicode/00FC/<U+00FC>\".")
-}
-
-func (s *Suite) Test_PlistChecker_checkSorted(c *check.C) {
-	t := s.Init(c)
-
-	lines := t.NewLines("PLIST",
-		PlistCvsID,
-		"bin/program2",
-		"bin/program1")
-
-	CheckLinesPlist(nil, lines)
-
-	t.CheckOutputLines(
-		"WARN: PLIST:3: \"bin/program1\" should be " +
-			"sorted before \"bin/program2\".")
-}
-
-func (s *Suite) Test_PlistChecker_checkDuplicate(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkDuplicate(c *check.C) {
 	t := s.Init(c)
 
 	lines := t.NewLines("PLIST",
@@ -797,7 +736,7 @@ func (s *Suite) Test_PlistChecker_checkDuplicate(c *check.C) {
 			"already appeared in line 2.")
 }
 
-func (s *Suite) Test_PlistChecker_checkDuplicate__OPSYS(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkDuplicate__OPSYS(c *check.C) {
 	t := s.Init(c)
 
 	t.SetUpPackage("category/package")
@@ -868,7 +807,7 @@ func (s *Suite) Test_PlistChecker_checkDuplicate__OPSYS(c *check.C) {
 		"ERROR: PLIST.common_end:3: Path bin/conditional is already listed in PLIST.common:3.")
 }
 
-func (s *Suite) Test_PlistChecker_checkPathBin(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathBin(c *check.C) {
 	t := s.Init(c)
 
 	lines := t.NewLines("PLIST",
@@ -882,7 +821,7 @@ func (s *Suite) Test_PlistChecker_checkPathBin(c *check.C) {
 		"WARN: PLIST:3: The bin/ directory should not have subdirectories.")
 }
 
-func (s *Suite) Test_PlistChecker_checkPathEtc(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathEtc(c *check.C) {
 	t := s.Init(c)
 
 	lines := t.NewLines("PLIST",
@@ -895,7 +834,7 @@ func (s *Suite) Test_PlistChecker_checkPathEtc(c *check.C) {
 		"ERROR: PLIST:2: Configuration files must not be registered in the PLIST.")
 }
 
-func (s *Suite) Test_PlistChecker_checkPathInfo(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathInfo(c *check.C) {
 	t := s.Init(c)
 
 	t.SetUpPackage("category/package")
@@ -911,7 +850,7 @@ func (s *Suite) Test_PlistChecker_checkPathInfo(c *check.C) {
 		"WARN: PLIST:2: Packages that install info files should set INFO_FILES in the Makefile.")
 }
 
-func (s *Suite) Test_PlistChecker_checkPathInfo__with_package(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathInfo__with_package(c *check.C) {
 	t := s.Init(c)
 
 	t.SetUpPackage("category/package",
@@ -927,7 +866,7 @@ func (s *Suite) Test_PlistChecker_checkPathInfo__with_package(c *check.C) {
 	t.CheckOutputEmpty()
 }
 
-func (s *Suite) Test_PlistChecker_checkPathInfo__without_package(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathInfo__without_package(c *check.C) {
 	t := s.Init(c)
 
 	lines := t.SetUpFileLines("PLIST",
@@ -939,7 +878,7 @@ func (s *Suite) Test_PlistChecker_checkPathInfo__without_package(c *check.C) {
 	t.CheckOutputEmpty()
 }
 
-func (s *Suite) Test_PlistChecker_checkPathLib(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathLib(c *check.C) {
 	t := s.Init(c)
 
 	lines := t.SetUpFileLines("PLIST",
@@ -963,7 +902,7 @@ func (s *Suite) Test_PlistChecker_checkPathLib(c *check.C) {
 			"Use ${PKGLOCALEDIR}/locale and set USE_PKGLOCALEDIR instead.")
 }
 
-func (s *Suite) Test_PlistChecker_checkPathLib__libiconv(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathLib__libiconv(c *check.C) {
 	t := s.Init(c)
 
 	t.SetUpPackage("converters/libiconv")
@@ -978,7 +917,7 @@ func (s *Suite) Test_PlistChecker_checkPathLib__libiconv(c *check.C) {
 	t.CheckOutputEmpty()
 }
 
-func (s *Suite) Test_PlistChecker_checkPathLib__libtool(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathLib__libtool(c *check.C) {
 	t := s.Init(c)
 
 	t.SetUpPackage("category/package",
@@ -994,7 +933,7 @@ func (s *Suite) Test_PlistChecker_checkPathLib__libtool(c *check.C) {
 	t.CheckOutputEmpty()
 }
 
-func (s *Suite) Test_PlistChecker_checkPathMan(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathMan(c *check.C) {
 	t := s.Init(c)
 
 	lines := t.SetUpFileLines("PLIST",
@@ -1012,7 +951,7 @@ func (s *Suite) Test_PlistChecker_checkPathMan(c *check.C) {
 		"WARN: ~/PLIST:5: Unknown section \"x\" for manual page.")
 }
 
-func (s *Suite) Test_PlistChecker_checkPathMan__gz(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathMan__gz(c *check.C) {
 	t := s.Init(c)
 
 	pkg := NewPackage(t.File("category/package"))
@@ -1032,7 +971,7 @@ func (s *Suite) Test_PlistChecker_checkPathMan__gz(c *check.C) {
 		"AUTOFIX: PLIST:2: Replacing \".gz\" with \"\".")
 }
 
-func (s *Suite) Test_PlistChecker_checkPathShare(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathShare(c *check.C) {
 	t := s.Init(c)
 
 	lines := t.SetUpFileLines("PLIST",
@@ -1057,7 +996,7 @@ func (s *Suite) Test_PlistChecker_checkPathShare(c *check.C) {
 		"WARN: ~/PLIST:7: Man pages should be installed into man/, not share/man/.")
 }
 
-func (s *Suite) Test_PlistChecker_checkPathShareIcons__using_gnome_icon_theme(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathShareIcons__using_gnome_icon_theme(c *check.C) {
 	t := s.Init(c)
 
 	t.CreateFileBuildlink3("graphics/gnome-icon-theme/buildlink3.mk")
@@ -1085,7 +1024,7 @@ func (s *Suite) Test_PlistChecker_checkPathShareIcons__using_gnome_icon_theme(c
 	t.CheckOutputEmpty()
 }
 
-func (s *Suite) Test_PlistChecker_checkPathShareIcons__gnome_icon_theme_itself(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathShareIcons__gnome_icon_theme_itself(c *check.C) {
 	t := s.Init(c)
 
 	t.CreateFileBuildlink3("graphics/gnome-icon-theme/buildlink3.mk",
@@ -1104,7 +1043,7 @@ func (s *Suite) Test_PlistChecker_checkPathShareIcons__gnome_icon_theme_itself(c
 	t.CheckOutputEmpty()
 }
 
-func (s *Suite) Test_PlistChecker_checkPathShareIcons(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathShareIcons(c *check.C) {
 	t := s.Init(c)
 
 	t.SetUpPackage("graphics/hicolor-icon-theme")
@@ -1130,7 +1069,7 @@ func (s *Suite) Test_PlistChecker_checkPathShareIcons(c *check.C) {
 			"Packages that install icon theme files should set ICON_THEMES.")
 }
 
-func (s *Suite) Test_PlistChecker_checkPathShareIcons__hicolor_ok(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathShareIcons__hicolor_ok(c *check.C) {
 	t := s.Init(c)
 
 	t.SetUpPackage("category/package",
@@ -1148,7 +1087,7 @@ func (s *Suite) Test_PlistChecker_checkPathShareIcons__hicolor_ok(c *check.C) {
 	t.CheckOutputEmpty()
 }
 
-func (s *Suite) Test_PlistChecker_checkPathCond(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkPathCond(c *check.C) {
 	t := s.Init(c)
 
 	t.SetUpPackage("category/package",
@@ -1176,7 +1115,7 @@ func (s *Suite) Test_PlistChecker_checkPathCond(c *check.C) {
 			"in the package Makefile.")
 }
 
-func (s *Suite) Test_PlistChecker_checkCond(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkCond(c *check.C) {
 	t := s.Init(c)
 
 	pkg := t.SetUpPackage("category/package",
@@ -1209,7 +1148,7 @@ func (s *Suite) Test_PlistChecker_checkCond(c *check.C) {
 // typically contains ${_o_} and ${_opt_}.
 //
 // See audio/cmus for an example package.
-func (s *Suite) Test_PlistChecker_checkCond__unresolvable_variable(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkCond__unresolvable_variable(c *check.C) {
 	t := s.Init(c)
 
 	t.SetUpPackage("category/package",
@@ -1230,7 +1169,7 @@ func (s *Suite) Test_PlistChecker_checkCond__unresolvable_variable(c *check.C) {
 			"Variable \"UNRESOLVABLE\" is used but not defined.")
 }
 
-func (s *Suite) Test_PlistChecker_checkCond__hacks_mk(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkCond__hacks_mk(c *check.C) {
 	t := s.Init(c)
 
 	t.SetUpPackage("category/package")
@@ -1253,7 +1192,7 @@ func (s *Suite) Test_PlistChecker_checkCond__hacks_mk(c *check.C) {
 			"in the package Makefile.")
 }
 
-func (s *Suite) Test_PlistChecker_checkOmf__autofix(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkOmf__autofix(c *check.C) {
 	t := s.Init(c)
 
 	t.CreateFileLines("mk/omf-scrollkeeper.mk",
@@ -1270,7 +1209,7 @@ func (s *Suite) Test_PlistChecker_checkOmf__autofix(c *check.C) {
 		"AUTOFIX: Makefile:20: Deleting this line.")
 }
 
-func (s *Suite) Test_PlistChecker_checkOmf__rationale(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkOmf__rationale(c *check.C) {
 	t := s.Init(c)
 
 	t.CreateFileLines("mk/omf-scrollkeeper.mk",
@@ -1286,7 +1225,7 @@ func (s *Suite) Test_PlistChecker_checkOmf__rationale(c *check.C) {
 			"their PLIST may include omf-scrollkeeper.mk.")
 }
 
-func (s *Suite) Test_PlistChecker_checkOmf__ok(c *check.C) {
+func (s *Suite) Test_PlistPathChecker_checkOmf__ok(c *check.C) {
 	t := s.Init(c)
 
 	t.CreateFileLines("mk/omf-scrollkeeper.mk",
@@ -1305,6 +1244,233 @@ func (s *Suite) Test_PlistChecker_checkOmf__ok(c *check.C) {
 		nil...)
 }
 
+func (s *Suite) Test_PlistAsciiChecker_Check(c *check.C) {
+	t := s.Init(c)
+
+	t.SetUpCommandLine("-Wall", "--explain")
+	lines := t.NewLines("PLIST",
+		PlistCvsID,
+
+		"dir1/fr\xFCher", // German, "back then", encoded in ISO 8859-1
+
+		// Subsequent non-ASCII filenames do not generate further messages
+		// since these filenames typically appear in groups, and issuing
+		// too many warnings quickly gets boring.
+		"dir1/\u00C4thernetz", // German
+
+		// This ASCII-only pathname enables the check again.
+		"dir2/aaa",
+		"dir2/\u0633\u0644\u0627\u0645", // Arabic: salaam
+
+		"dir2/\uC548\uB148", // Korean: annyeong
+
+		// This ASCII-only pathname enables the check again.
+		"dir3/ascii-only",
+
+		// Any comment suppresses the check for the next contiguous
+		// sequence of non-ASCII filenames.
+		"@comment The next file is non-ASCII on purpose.",
+		"dir3/\U0001F603", // Smiling face with open mouth
+
+		// This ASCII-only pathname enables the check again.
+		"sbin/iconv",
+
+		"sbin/\U0001F603", // Smiling face with open mouth
+
+		// Directives other than comments do not allow non-ASCII.
+		"unicode/00FC/reset",
+		"@exec true",
+		"unicode/00FC/\u00FC", // u-umlaut
+	)
+
+	CheckLinesPlist(nil, lines)
+
+	t.CheckOutputLines(
+		"WARN: PLIST:2: Non-ASCII filename \"dir1/fr<0xFC>her\".",
+		"",
+		"\tThe great majority of filenames installed by pkgsrc packages are",
+		"\tASCII-only. Filenames containing non-ASCII characters can cause",
+		"\tvarious problems since their name may already be different when",
+		"\tanother character encoding is set in the locale.",
+		"",
+		"\tTo mark a filename as intentionally non-ASCII, insert a PLIST",
+		"\t@comment with a convincing reason directly above this line. That",
+		"\tcomment will allow this line and the lines directly below it to",
+		"\tcontain non-ASCII filenames.",
+		"",
+		"WARN: PLIST:5: Non-ASCII filename \"dir2/<U+0633><U+0644><U+0627><U+0645>\".",
+		"WARN: PLIST:11: Non-ASCII filename \"sbin/<U+1F603>\".",
+		"WARN: PLIST:14: Non-ASCII filename \"unicode/00FC/<U+00FC>\".")
+}
+
+func (s *Suite) Test_PlistSortChecker__unsortable(c *check.C) {
+	t := s.Init(c)
+
+	t.SetUpCommandLine("-Wall", "--show-autofix")
+	lines := t.SetUpFileLines("PLIST",
+		PlistCvsID,
+		"bin/program${OPSYS}",
+		"@exec true",
+		"bin/program1")
+
+	t.EnableTracingToLog()
+	CheckLinesPlist(nil, lines)
+
+	t.CheckOutputLines(
+		"TRACE: + CheckLinesPlist(\"~/PLIST\")",
+		"TRACE: 1 + Lines.CheckCvsID(\"@comment \", \"@comment \")",
+		"TRACE: 1 - Lines.CheckCvsID(\"@comment \", \"@comment \")",
+		"TRACE: 1   ~/PLIST:2: bin/program${OPSYS}: This line prevents pkglint from sorting the PLIST automatically.",
+		"TRACE: 1 + SaveAutofixChanges()",
+		"TRACE: 1 - SaveAutofixChanges()",
+		"TRACE: - CheckLinesPlist(\"~/PLIST\")")
+}
+
+// Two lines start with the same placeholder, but the remaining text is
+// not sorted correctly.
+func (s *Suite) Test_PlistSortChecker__placeholder_unsorted(c *check.C) {
+	t := s.Init(c)
+
+	t.SetUpCommandLine("-Wall", "--show-autofix")
+	lines := t.SetUpFileLines("PLIST",
+		PlistCvsID,
+		"bin/rabbiter",
+		"${RUBY_VENDORLIB}/rabbiter.rb",
+		// TODO: warn that version.rb belongs below gettext.rb.
+		"${RUBY_VENDORLIB}/rabbiter/version.rb",
+		"${RUBY_VENDORLIB}/rabbiter/gettext.rb",
+		"share/locale/ja/LC_MESSAGES/rabbiter.mo")
+
+	CheckLinesPlist(nil, lines)
+
+	t.CheckOutputEmpty()
+}
+
+// There are two lines containing ${GEM_HOME}, and they are far apart.
+// But assuming that ${GEM_EXTSDIR} and ${GEM_LIBDIR} are both
+// subdirectories of ${GEM_HOME}, they are correctly sorted.
+func (s *Suite) Test_PlistSortChecker__placeholder_prefix(c *check.C) {
+	t := s.Init(c)
+
+	t.SetUpCommandLine("-Wall", "--show-autofix")
+	lines := t.SetUpFileLines("PLIST",
+		PlistCvsID,
+		"${GEM_HOME}/cache/${GEM_NAME}.gem",
+		"${GEM_EXTSDIR}/gem.build_complete",
+		"${GEM_LIBDIR}/COPYING.LIB",
+		"${GEM_LIBDIR}/test/test-source-view.rb",
+		"${GEM_HOME}/specifications/${GEM_NAME}.gemspec")
+
+	CheckLinesPlist(nil, lines)
+
+	t.CheckOutputEmpty()
+}
+
+// If ${B} is "${A}/file1", the resulting PLIST is in correct order.
+// This combination is unlikely, though.
+func (s *Suite) Test_PlistSortChecker__placeholder_impossible(c *check.C) {
+	t := s.Init(c)
+
+	t.SetUpCommandLine("-Wall", "--show-autofix")
+	lines := t.SetUpFileLines("PLIST",
+		PlistCvsID,
+		"${A}/file",
+		"${B}/file",
+		"${A}/file2")
+
+	CheckLinesPlist(nil, lines)
+
+	t.CheckOutputEmpty()
+}
+
+func (s *Suite) Test_PlistSortChecker_Check(c *check.C) {
+	t := s.Init(c)
+
+	lines := t.NewLines("PLIST",
+		PlistCvsID,
+		"bin/program2",
+		"bin/program1")
+
+	CheckLinesPlist(nil, lines)
+
+	t.CheckOutputLines(
+		"WARN: PLIST:3: \"bin/program1\" should be " +
+			"sorted before \"bin/program2\".")
+}
+
+func (s *Suite) Test_PlistSortChecker_Sort(c *check.C) {
+	t := s.Init(c)
+
+	t.SetUpCommandLine("--autofix")
+	lines := t.SetUpFileLines("PLIST",
+		PlistCvsID,
+		"@comment Do not remove",
+		"A",
+		"b",
+		"CCC",
+		"lib/${UNKNOWN}.la",
+		"C",
+		"ddd",
+		"@exec echo \"after ddd\"", // Makes the PLIST unsortable
+		"sbin/program",
+		"${PLIST.one}bin/program",
+		"man/man1/program.1",
+		"${PLIST.two}bin/program2",
+		"lib/before.la",
+		"${PLIST.linux}${PLIST.x86_64}lib/lib-linux-x86_64.so", // Double condition, see graphics/graphviz
+		"lib/after.la",
+		"@exec echo \"after lib/after.la\"")
+	plines := extractPlistConditions(lines)
+
+	var sorter1 PlistSortChecker
+	t.EnableTracingToLog()
+	sorter1.Sort(lines.Lines, plines)
+	t.DisableTracing()
+	t.CheckOutputLines(
+		"TRACE:   ~/PLIST:6: lib/${UNKNOWN}.la: " +
+			"This line prevents pkglint from sorting the PLIST automatically.")
+
+	lines = t.SetUpFileLines("PLIST",
+		PlistCvsID,
+		"@comment Do not remove",
+		"A",
+		"b",
+		"CCC",
+		"C",
+		"ddd",
+		"sbin/program",
+		"${PLIST.one}bin/program",
+		"man/man1/program.1",
+		"${PLIST.two}bin/program2",
+		"lib/before.la",
+		"${PLIST.linux}${PLIST.x86_64}lib/lib-linux-x86_64.so", // Double condition, see graphics/graphviz
+		"lib/after.la",
+		"@exec echo \"after lib/after.la\"")
+	lines2 := extractPlistConditions(lines)
+	var sorter2 PlistSortChecker
+	sorter2.Sort(lines.Lines, lines2)
+	SaveAutofixChanges(lines)
+
+	t.CheckOutputLines(
+		"AUTOFIX: ~/PLIST:3: Sorting the whole file.")
+	t.CheckFileLines("PLIST",
+		PlistCvsID,
+		"@comment Do not remove", // The header ends here
+		"A",
+		"C",
+		"CCC",
+		"b",
+		"${PLIST.one}bin/program", // Conditional lines are ignored during sorting
+		"${PLIST.two}bin/program2",
+		"ddd",
+		"lib/after.la",
+		"lib/before.la",
+		"${PLIST.linux}${PLIST.x86_64}lib/lib-linux-x86_64.so",
+		"man/man1/program.1",
+		"sbin/program",
+		"@exec echo \"after lib/after.la\"") // The footer starts here
+}
+
 func (s *Suite) Test_PlistLine_Autofix(c *check.C) {
 	t := s.Init(c)
 
@@ -1376,11 +1542,11 @@ func (s *Suite) Test_PlistLine_RelLine(c *check.C) {
 		"WARN: PLIST:2: Warning, see line 2.")
 }
 
-func (s *Suite) Test_PlistLine_HasPath(c *check.C) {
+func (s *Suite) Test_PlistLine_IsPath(c *check.C) {
 	t := s.Init(c)
 
 	test := func(text string, hasPath bool) {
-		t.CheckEquals((&PlistLine{text: text}).HasPath(), hasPath)
+		t.CheckEquals((&PlistLine{text: text}).IsPath(), hasPath)
 	}
 
 	test("abc", true)
@@ -1397,11 +1563,11 @@ func (s *Suite) Test_PlistLine_HasPath(c *check.C) {
 	test("bin/${VAR}", true)
 }
 
-func (s *Suite) Test_PlistLine_HasPlainPath(c *check.C) {
+func (s *Suite) Test_PlistLine_IsPlainPath(c *check.C) {
 	t := s.Init(c)
 
 	test := func(text string, hasPlainPath bool) {
-		t.CheckEquals((&PlistLine{text: text}).HasPlainPath(), hasPlainPath)
+		t.CheckEquals((&PlistLine{text: text}).IsPlainPath(), hasPlainPath)
 	}
 
 	test("abc", true)
@@ -1429,6 +1595,20 @@ func (s *Suite) Test_PlistLine_Path(c *check.C) {
 		func() { (&PlistLine{text: "/absolute"}).Path() })
 }
 
+func (s *Suite) Test_PlistLine_IsDirective(c *check.C) {
+	t := s.Init(c)
+
+	t.CheckEquals(
+		(&PlistLine{text: "@exec echo done"}).IsDirective(),
+		true)
+	t.CheckEquals(
+		(&PlistLine{text: "bin/program"}).IsDirective(),
+		false)
+	t.CheckEquals(
+		(&PlistLine{text: "${BINDIR}/program"}).IsDirective(),
+		false)
+}
+
 func (s *Suite) Test_PlistLine_CheckTrailingWhitespace(c *check.C) {
 	t := s.Init(c)
 
@@ -1476,118 +1656,6 @@ func (s *Suite) Test_PlistLine_CheckDirective(c *check.C) {
 		"WARN: ~/PLIST:13: Unknown PLIST directive \"@unknown\".")
 }
 
-func (s *Suite) Test_plistLineSorter__unsortable(c *check.C) {
-	t := s.Init(c)
-
-	t.SetUpCommandLine("-Wall", "--show-autofix")
-	lines := t.SetUpFileLines("PLIST",
-		PlistCvsID,
-		"bin/program${OPSYS}",
-		"@exec true",
-		"bin/program1")
-
-	t.EnableTracingToLog()
-	CheckLinesPlist(nil, lines)
-
-	t.CheckOutputLines(
-		"TRACE: + CheckLinesPlist(\"~/PLIST\")",
-		"TRACE: 1 + Lines.CheckCvsID(\"@comment \", \"@comment \")",
-		"TRACE: 1 - Lines.CheckCvsID(\"@comment \", \"@comment \")",
-		"TRACE: 1   ~/PLIST:2: bin/program${OPSYS}: This line prevents pkglint from sorting the PLIST automatically.",
-		"TRACE: 1 + SaveAutofixChanges()",
-		"TRACE: 1 - SaveAutofixChanges()",
-		"TRACE: - CheckLinesPlist(\"~/PLIST\")")
-}
-
-func (s *Suite) Test_newPlistLineSorter__only_comments(c *check.C) {
-	t := s.Init(c)
-
-	lines := t.NewLines("PLIST",
-		PlistCvsID,
-		"@comment intentionally left empty")
-
-	CheckLinesPlist(nil, lines)
-
-	t.CheckOutputEmpty()
-}
-
-func (s *Suite) Test_plistLineSorter_Sort(c *check.C) {
-	t := s.Init(c)
-
-	t.SetUpCommandLine("--autofix")
-	lines := t.SetUpFileLines("PLIST",
-		PlistCvsID,
-		"@comment Do not remove",
-		"A",
-		"b",
-		"CCC",
-		"lib/${UNKNOWN}.la",
-		"C",
-		"ddd",
-		"@exec echo \"after ddd\"", // Makes the PLIST unsortable
-		"sbin/program",
-		"${PLIST.one}bin/program",
-		"man/man1/program.1",
-		"${PLIST.two}bin/program2",
-		"lib/before.la",
-		"${PLIST.linux}${PLIST.x86_64}lib/lib-linux-x86_64.so", // Double condition, see graphics/graphviz
-		"lib/after.la",
-		"@exec echo \"after lib/after.la\"")
-	ck := PlistChecker{
-		nil,
-		nil,
-		nil,
-		"",
-		Once{},
-		Once{},
-		Once{},
-		OncePerString{},
-		false,
-	}
-	plines := ck.newLines(lines)
-
-	sorter1 := newPlistLineSorter(plines)
-	t.CheckEquals(sorter1.unsortable, lines.Lines[5])
-
-	cleanedLines := append(append(lines.Lines[0:5], lines.Lines[6:8]...), lines.Lines[9:]...) // Remove ${UNKNOWN} and @exec
-
-	sorter2 := newPlistLineSorter((&PlistChecker{
-		nil,
-		nil,
-		nil,
-		"",
-		Once{},
-		Once{},
-		Once{},
-		OncePerString{},
-		false,
-	}).
-		newLines(NewLines(lines.Filename, cleanedLines)))
-
-	t.CheckNil(sorter2.unsortable)
-
-	sorter2.Sort()
-
-	t.CheckOutputLines(
-		"AUTOFIX: ~/PLIST:3: Sorting the whole file.")
-	t.CheckFileLines("PLIST",
-		PlistCvsID,
-		"@comment Do not remove", // The header ends here
-		"A",
-		"C",
-		"CCC",
-		"b",
-		"${PLIST.one}bin/program", // Conditional lines are ignored during sorting
-		"${PLIST.two}bin/program2",
-		"ddd",
-		"lib/after.la",
-		"lib/before.la",
-		"${PLIST.linux}${PLIST.x86_64}lib/lib-linux-x86_64.so",
-		"man/man1/program.1",
-		"sbin/program",
-		"@exec echo \"after lib/after.la\"") // The footer starts here
-}
-
 func (s *Suite) Test_NewPlistRank(c *check.C) {
 	t := s.Init(c)
 
@@ -1665,12 +1733,12 @@ func (s *Suite) Test_PlistLines_Add(c *check.C) {
 	lines := NewPlistLines()
 
 	for _, line := range plistLines {
-		if line.HasPath() {
+		if line.IsPath() {
 			lines.Add(line, NewPlistRank(line.Line.Basename), true)
 		}
 	}
 	for _, line := range plistCommonLines {
-		if line.HasPath() {
+		if line.IsPath() {
 			lines.Add(line, NewPlistRank(line.Line.Basename), true)
 		}
 	}
