@@ -1391,14 +1391,16 @@ func (s *Suite) Test_ShellLineChecker_checkHiddenAndSuppress(c *check.C) {
 		"\t@${DELAYED_WARNING_MSG} 'ok'",
 		"\t@${DO_NADA} 'ok'",
 		"\t@${ECHO} 'ok'",
-		"\t@${ECHO_MSG} 'ok'",
+		"\t@echo 'ok'",
 		"\t@${ECHO_N} 'ok'",
+		"\t@${ECHO_MSG} 'ok'",
 		"\t@${ERROR_CAT} 'ok'",
 		"\t@${ERROR_MSG} 'ok'",
 		"\t@${FAIL_MSG} 'ok'",
 		"\t@${INFO_MSG} 'ok'",
 		"\t@${PHASE_MSG} 'ok'",
 		"\t@${PRINTF} 'ok'",
+		"\t@printf 'ok'",
 		"\t@${SHCOMMENT} 'ok'",
 		"\t@${STEP_MSG} 'ok'",
 		"\t@${WARNING_CAT} 'ok'",
